#
# spec file for package ddclient
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


#Compat macro for new _fillupdir macro introduced in Nov 2017
%if ! %{defined _fillupdir}
  %define _fillupdir /var/adm/fillup-templates
%endif

Name:           ddclient
Summary:        A Perl Client to Update Dynamic DNS Entries
License:        GPL-2.0+
Group:          Productivity/Networking/DNS/Utilities
Version:        3.8.3
Release:        lp150.1.4
Url:            http://ddclient.sourceforge.net/
Source0:        http://prdownloads.sourceforge.net/%{name}/%{name}-%{version}.tar.bz2
Source1:        %{name}.service
Source2:        %{name}.sysconfig
Source3:        %{name}-tmpfiles.conf
Source4:        rc.%{name}
Patch0:         %{name}-3.8.1-config.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch
Requires(pre):  %fillup_prereq
Requires(pre):  pwdutils

%if 0%{?suse_version} >= 1230
BuildRequires:  pkgconfig(systemd)
%{?systemd_requires}
%define has_systemd 1
%endif

Requires:       perl >= 5.004
Recommends:     perl-IO-Socket-SSL

%description
ddclient is a small full-featured client requiring only Perl. Supported
features include daemon operation, manual and automatic updates, static
and dynamic updates, optimized updates for multiple addresses, MX, wild
cards, abuse avoidance, retry for failed updates, and status updates to
syslog and through e-mail. ddclient can obtain the IP address from any
interface, through a Web-based IP detection service, and for multiple
routers using custom FW definitions. It also provides full support for
DynDNS.org's NIC2 protocol. Support is also included for other dynamic
DNS services. Comes with sample scripts for use with DHCP, PPP, and
cron.

%prep
%setup
%patch0
rm -f sample-etc_ddclient.conf.orig
chmod a-x sample-*
mkdir examples
mv sample-* examples

%build
#%%configure
#make
# If the package provides automatic testing
#make test
# nothing to do here (yet)

%install
#%{_sbindir}/groupadd -r %{name} 2>/dev/null || :
#%{_sbindir}/useradd -c "DDClient User" -d %{_localstatedir}/cache/%{name} \
#  -g %{name} -r -s /bin/false %{name} 2>/dev/null || :

#make DESTDIR=$RPM_BUILD_ROOT install
%{__install} -D -m 755 %{name} %{buildroot}%{_sbindir}/%{name}
%{__install} -D -m 600 examples/sample-etc_ddclient.conf %{buildroot}%{_sysconfdir}/%{name}.conf
%if 0%{?has_systemd}
%{__sed} -i -e "s,/var/run/,/run/%{name}/," %{buildroot}%{_sysconfdir}/%{name}.conf
%else
%{__sed} -i -e "s,/var/run/,/var/run/%{name}/," %{buildroot}%{_sysconfdir}/%{name}.conf
%endif
# init script and config file
%if 0%{?has_systemd}
%{__install} -D -m 644 %{SOURCE1} %{buildroot}/%{_unitdir}/%{name}.service
%{__install} -D -m 644 %{SOURCE3} %{buildroot}%{_libexecdir}/tmpfiles.d/%{name}.conf
%{__ln_s} %{_sbindir}/service %{buildroot}%{_sbindir}/rc%{name}
%else
%{__install} -D -m 755 %{SOURCE4} %{buildroot}%{_sysconfdir}/init.d/%{name}
%{__ln_s} %{_sysconfdir}/init.d/%{name} %{buildroot}%{_sbindir}/rc%{name}
%endif
%{__install} -d -m 755 %{buildroot}%{_fillupdir}
%{__install} -m 644 %{SOURCE2} %{buildroot}%{_fillupdir}/sysconfig.%{name}
%{__install} -d -m 755 %{buildroot}/var/cache/%{name}
%if 0%{?has_systemd}
%{__install} -d -m 755 %{buildroot}/run/%{name}
%else
%{__install} -d -m 755 %{buildroot}%{_localstatedir}/run/%{name}
%endif

%pre
if [[ -z $(%{_bindir}/getent group %{name} 2>/dev/null) ]]; then
  %{_sbindir}/groupadd -r %{name} 2>/dev/null
fi
if [[ -z $(%{_bindir}/getent passwd %{name} 2>/dev/null) ]]; then
  %{_sbindir}/useradd -c "DDClient User" -d %{_localstatedir}/cache/%{name} \
    -g %{name} -r -s /bin/false %{name} 2>/dev/null
fi
%if 0%{?has_systemd}
%service_add_pre %{name}.service
%{__install} -d -m 755 -o %{name} -g root /run/%{name}
%else
%{__install} -d -m 755 -o %{name} -g root %{_localstatedir}/run/%{name}
%endif

%post
%{fillup_only}
%if 0%{?has_systemd}
%service_add_post %{name}.service
%endif

%preun
%if 0%{?has_systemd}
%service_del_preun %{name}.service
%else
%stop_on_removal ddclient
%endif

%postun
%if 0%{?has_systemd}
%service_del_postun %{name}.service
%else
%restart_on_update ddclient
%insserv_cleanup
%endif

%files
%defattr(-, root, root)
%doc COPY* README* examples
%config(noreplace) %attr(600,%{name},root) %{_sysconfdir}/%{name}.conf
%if 0%{?has_systemd}
%{_unitdir}/%{name}.service
%{_libexecdir}/tmpfiles.d/ddclient.conf
%ghost %dir %attr(755,%{name},root) /run/%{name}
%else
/etc/init.d/%{name}
%ghost %dir %attr(755,%{name},root) %{_localstatedir}/run/%{name}
%endif
%{_sbindir}/%{name}
%{_sbindir}/rc%{name}
%{_fillupdir}/sysconfig.%{name}
%dir %attr(700,%{name},root) %{_localstatedir}/cache/%{name}

%changelog
* Thu Nov 23 2017 rbrown@suse.com
- Replace references to /var/adm/fillup-templates with new
  %%_fillupdir macro (boo#1069468)
* Fri Feb  3 2017 josef.moellers@suse.com
- Upgrade to ddclient-3.8.3.
  * added Alpine Linux init scritp - patch send by @Tal on github.
  * adding support for nsupdate - patch send by @droe on github
  * allow log username-password combinations - patch send by @dirdi on github
  * adding support for cloudflare - patch send by @roberthawdon on github
  * adding support for duckdns - patch send by @gkranis
* Fri Jan  8 2016 chris@computersalat.de
- fix for boo#903588
- revert patch change
- recover deleted changes (rev34)
- systemd fix
  * conf file must be accessible only by its owner
* Mon Jun 30 2014 pth@suse.de
- Use perl_requires instead of harcoding a value.
* Wed Jun 18 2014 stefan.fent@suse.com
- fix pidfile path in /etc/ddclient.conf and set ownership to ddclient
- create user and group ddclient (bnc#881520)
- create /run/ddclient/ with user and group ddclient if not yet
  available in %%pre
* Thu May 22 2014 chris@computersalat.de
- update systemd stuff
  * add {?has_systemd} to fix build for Systems using init scripts
- spec cleanup
  * add missing BuildRoot
* Tue May 20 2014 jsegitz@novell.com
- ensure proper handling of .service files with %%service_add_pre
* Tue Dec 31 2013 benoit.monin@gmx.fr
- update to 3.8.2
  * adding support by ChangeIP
  * sha-1 patch  to allow Digest::SHA
  * allow reuse of use
  * preventing deep sleep - see bug #46
  * Fallback to iproute if ifconfig doesn't work
- drop ddclient-3.8.1-update_nic.patch: upstream changed the "use"
  logic
- move all sample-* to examples under the documentation directory
- update source url on sourceforge
* Wed Dec  4 2013 seife+obs@b1-systems.com
- fix the breakage from last submission:
  * service file was put into tmpfiles.d
  * tmpfiles config was put into systemd service dir
  * rcddclient link was broken (pointed to "service" file)
- fix rpmlint warnings, also introduced by last submission:
  * service files and tmpdir config are neither config files nor
    should be executable
- package is noarch, mark it as such
- documentation should not have executable bit set
* Sun Oct 27 2013 p.drouand@gmail.com
- Improve systemd support for openSUSE >= 12.3
* Thu May 16 2013 seife+obs@b1-systems.com
- more init-script fixes:
  - startproc now needs the pidfile parameter (or it woulld look
    for "perl.pid". Sorry, should have run more tests.
  - while I'm at it, get the pidfile from the config file in case
    the user would have changed it
* Wed May 15 2013 seife+obs@b1-systems.com
- fix init script: start ddclient with "/usr/bin/perl ddclient",
  otherwise startproc will falsely report that starting failed.
* Wed Oct 24 2012 chris@computersalat.de
- rework config patch
  * ddclient.conf: add example for selfhost (http://selfhost.de)
* Tue Sep 25 2012 binli@opensuse.org
- Update ddclient-3.8.1-config.patch to check the configuraton file
  from /etc instead of /etc/ddclient (bnc#781699).
* Mon Jan  9 2012 chris@computersalat.de
- update to 3.8.1
  * Fixing #28: FreeDNS.afraid.org changed api slightly
  * Added dtdns-support
  * Added support for longer password
  * Added cisco-asa patch
  * Added support for LoopiaDNS
- rebase patches
* Wed Oct 19 2011 ro@suse.de
- remove leftover debug line in init script
* Sat Oct 15 2011 ro@suse.de
- upgrade Suggests for perl-IO-Socket-SSL to Recommends
  (bnc#723688)
* Sun Sep 18 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
  (cf. packaging guidelines)
* Mon Aug 29 2011 ro@suse.de
- work on init-script so that start/status/stop at least work
  (bnc#267306)
* Tue Sep  1 2009 chris@computersalat.de
- rework config patch
  o now one patch
  o merged
  - ddclient-3.6.3-config.patch
  - ddclient-3.7.1-config.patch
  - ddclient-3.7.1-sysconfig.patch
    to ddclient-3.8.0-config.patch
  o defaults for ppp0
- added update_nic.patch
  * opt('use') should have priority to global-defaults
- init script
  o beautify
  o should start rp-pppoe
  o ppp0 as a "use=" default if not set in ddclient.conf
- sysconfig
  o added argument list for DDCLIENT_OPTIONS
- cleanup spec
* Sun Aug 30 2009 coolo@novell.com
- use %%patch0
* Wed Aug 26 2009 mls@suse.de
- make patch0 usage consistent
* Mon Feb  2 2009 kssingvo@suse.de
- made rpmlint more happy
- removed unneccessary .orig file to avoid build issue
* Wed Jan 28 2009 kssingvo@suse.de
- new version 3.8.0:
  * better password handling
  * ddclient wrapper now included
  * some remarks concerning postscript in sample config file
  * support for multiple IP adresses
  * namecheap patch
  * Preventing error while reading cache when ip wasn't set correctly
    before
  * Preventing an error when trying to send a message on mail-failure
  * mail-on-kill functionality
  * documentation changes
* Tue Jan 27 2009 kukuk@suse.de
- Add PreRequires
* Thu Aug 30 2007 kssingvo@suse.de
- config file ddclient.conf now with noreplace (bugzilla#305533)
* Tue Aug  7 2007 kssingvo@suse.de
- upgrade to version 3.7.3:
  * fixed typo for dnspark
  * Renamed dyndns.org to dyndns.com
  * opendns support added
  * several debian/ubuntu patches included
  * Readme changes
  * signature modified
  * typo in namecheap support
* Thu Jun 14 2007 kssingvo@suse.de
- upgrade to version 3.7.2:
  * updated easydns support
  * fix for 'fw' in case of debug
  * ssl call changed
  * easydns.patch and eurodns.patch now included
- enable_fw patch removed, now in upstream version included
* Thu May  3 2007 kssingvo@suse.de
- added sysconfig file, as suggested in bugzilla#268138
- added /var/cache/ddclient (bugzilla#268138)
* Tue Apr  3 2007 kssingvo@suse.de
- fixed issue in debug messages (bugzilla#250170)
* Tue Feb 13 2007 kssingvo@suse.de
- disabled ssl in default config (bugzilla#232005)
* Mon Feb 12 2007 kssingvo@suse.de
- update to version 3.7.1:
  * URL of zoneedit has changed (see bug #1558483)
  * Added initscript for Ubuntu (posted by Paolo Martinelli)
  * Added patch "Patch: Treat --daemon values as intervals"
    (submitted by James deBoer)
  * Don't send any mail when in not running daemon mode (patch
    submitted by Daniel Thaler)
  * Changed Changelog syntax
  * Applied patches submitted by Torsten:
    abuse_msg.diff: ddclient still reports the email to contact
    dyndns.org but they prefer a web form today (IIRC). This patch
    adjusts the abuse warning printed by ddclient.
    cachedir.diff: Original ddclient stores a cache file in /etc
    which would belong in /var/cache in my opinion and according
    to the FHS.
    help_nonroot.diff: Allow calling the help function as non-root.
    update-new-config.patch: Force update if config has changed
    smc-barricade-7401bra.patch: Support for SMC Barricade 7401BRA
    FW firewall
    cisco_fw.diff: Use configured hostname for firewall access with
  - use=cisco (closes: #345712). Thanks to Per Carlson for the
    patch!  See http://bugs.debian.org/345712.
    maxinterval.diff: Increase max interval for updates.
    See http://bugs.debian.org/cgi-bin/bugreport.cgi?bug=129370
    http://www.dyndns.com/support/services/dyndns/faq.html#q15
- added Suggests: for perl-IO-SSL-Socket (bugzilla#232005)
- adapted /etc config patch to new version
* Mon Jan  8 2007 kssingvo@suse.de
- fixed checkproc in init script (bugzilla#229460)
* Wed Sep 20 2006 kssingvo@suse.de
- added init script (bugzilla#201548)
* Wed Jun 28 2006 kssingvo@suse.de
- update to version 3.7.0:
- support of many new routers
- fix to have a '#' char in the password
- renamed .orig to _orig in %%doc section
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Jan 11 2006 kssingvo@suse.de
- update to version 3.6.7
* Tue Jul 26 2005 kssingvo@suse.de
- update to version 3.6.6
* Tue Mar 29 2005 kssingvo@suse.de
- fix of config directory location (bugzilla#74539)
* Tue Feb  1 2005 kssingvo@suse.de
- new version 3.6.5: there was a bug in the linksys-ver2
* Thu Nov  4 2004 kssingvo@suse.de
- new version 3.6.4 and now maintained at sourceforge
* Sun Jan 11 2004 adrian@suse.de
- fix build as user
* Wed Aug 13 2003 kssingvo@suse.de
- fixed defaults (bugzilla#27701)
* Tue Jun 24 2003 kssingvo@suse.de
- upgraded to ddclient-3.6.3
* Tue Jan 14 2003 kssingvo@suse.de
- updated to ddclient-3.6.3beta3
* Mon Oct 28 2002 kssingvo@suse.de
- first shot.
